/*
   <p>Convert a string for output so that  non-printable bytes or control
      codes are represented in hexadecimal as '<hh>'</p>

   <kbd>
   <b>environ - C programming support functions</b><br>
   Copyright (C) 2005  Martin C Gregorie
   
   This program is free software; you can redistribute it and/or
   modify it under the terms of the Lesser GNU General Public License.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the Lesser GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
   </kbd>
  
   <p>Contact Martin Gregorie at <i>martin@gregorie.org</i></p>
*/

#include <stdlib.h>
#include <string.h>
#include <environ.h>

/* 
   Returns a pointer to an internal static string containing 
   the converted string. Each byte that is printable and not a
   control character is unmodified, but the rest are replaced
   the hexadecimal equivalent formatted as "<hh>".

   This function should not appear more than once in a formatted print
   statement because all such calls be evaluated before the formatted
   output is generated. By this time the internal static string will
   contain the result of the final call and all such byte decodings
   will apparently result in the same (final) value. 

   If this is necessary, capture each decoded value in a separate
   string and print from these:

   <pre>
      char buff[80];
      strcpy(buff, strhex(s));
      fprint("Read '%s'\n", buff);
   </pre>

   This function is primarily intended as a debugging aid.
*/

static char *buff = NULL;

char *strhex(char *s)
{
   int            i;
   int            n = strlen(s);
   int            l = n * 4 + 1;
   char           *cbuff;

   if (buff != NULL)
      free(buff);
      
   buff = get_space(l);
   buff[0] = '\0';
   buff[l] = '\0';
   for (i = 0; i < n; i++)
   {
      cbuff = byteout(s[i]);
      strncat(buff, cbuff, l);
   }

   return buff;
}


